@@ -10,7 +10,8 @@ import gettext
 
 path = os.path.realpath(os.path.abspath(os.path.join(os.path.split(
     inspect.getfile(inspect.currentframe()))[0],os.path.normpath("lang"))))
-_ = translation = gettext.translation(domain='intents', localedir=path, languages=[configuration['lang']]).ugettext
+_ = translation = gettext.translation(domain='intents', localedir=path, fallback=True,
+                                      languages=[configuration['lang']]).ugettext
 
 class Intents:
     def __init__(self, lisa=None):
